@@ -31,7 +31,7 @@ class MinioBackend(BackendBase):
             if ret:
                 print('upload success.')
                 return True, '{}/{}'.format(_bucket, bucket_name)
-            print('upload failed.')
+            print('upload failed: {}'.format(e))
             return False, e
         except Exception as e:
             return False, traceback.format_exc()
