@@ -3,6 +3,7 @@ import traceback
 from gnsq import Producer, Consumer, Message, NsqdHTTPClient
 from ansq import open_connection
 from ansq.tcp.connection import ConnectionStatus
+from ansq.tcp.exceptions import ConnectionClosedError
 import asyncio
 import orjson
 import time
@@ -44,8 +45,23 @@ class MQManager(Singleton):
             traceback.print_exc()
 
     async def get_mq_conn(self):
-        if not hasattr(self, 'mq'):
+        if not hasattr(self, 'mq') or self.mq.status.is_closed:
             self.mq = await open_connection(self.host, self.port)
+        else:
+            if not self.mq.status.is_connected:
+                is_timeout = False
+                t = time.time()
+                while self.mq.status.is_reconnecting:
+                    if time.time() - t > 5:
+                        is_timeout = True
+                        break
+                
+                if self.mq.status.is_connected:
+                    return self.mq
+                
+                if is_timeout:
+                    await self.close_async()
+                    self.mq = await open_connection(self.host, self.port)
         
         return self.mq
             
@@ -107,6 +123,19 @@ class MQManager(Singleton):
             print('nsq publish success!')
         return ret
 
+    async def __mq_pub(self, topic, message, mq=None, tries=0):
+        if tries > 5:
+            return False
+        if mq is None:
+            mq = await self.get_mq_conn()
+        try:
+            resp = await mq.pub(topic, message)
+            return resp.is_ok
+        except ConnectionClosedError as e:
+            await self.close_async()
+            return await self.__mq_pub(topic, message, None, tries+1)
+
+
     async def async_publish(self, topic, message, mq=None):
         try:
             if isinstance(message, str):
@@ -120,19 +149,11 @@ class MQManager(Singleton):
             if mq is None:
                 mq = await self.get_mq_conn()
 
-            ret = (await mq.pub(topic, message)).is_ok
-            max_t = 5
-            t = 0
-            while not ret and t < max_t: 
-                try:
-                    ret = (await mq.pub(topic, message)).is_ok
-                except:
-                    ret = False
-                t += 1
+            ret = await self.__mq_pub(topic, message)
             return ret
         except Exception as e:
             print(traceback.print_exc())
-            ret = False
+            return False
 
 if __name__ == "__main__":
     manager = MQManager('kafka.ai.hamuna.club', 34150, async_mq=True)
